summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sync/profile_sync_service.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/sync/profile_sync_service.cc')
-rw-r--r--chrome/browser/sync/profile_sync_service.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/sync/profile_sync_service.cc b/chrome/browser/sync/profile_sync_service.cc
index f35939d..636c17f 100644
--- a/chrome/browser/sync/profile_sync_service.cc
+++ b/chrome/browser/sync/profile_sync_service.cc
@@ -122,7 +122,7 @@ void ProfileSyncService::StartUp() {
registrar_.Add(this, NotificationType::BOOKMARK_MODEL_LOADED,
Source<Profile>(profile_));
// Create new model assocation manager and change processor.
model_associator_ = new ModelAssociator(this);
change_processor_->set_model_associator(model_associator_);
@@ -343,7 +343,7 @@ void ProfileSyncService::OnUserAcceptedMergeAndSync() {
UMA_HISTOGRAM_MEDIUM_TIMES("Sync.UserPerceivedBookmarkAssociation",
base::TimeTicks::Now() - start_time);
if (!merge_success) {
- LOG(ERROR) << "Model assocation failed.";
+ LOG(ERROR) << "Model association failed.";
OnUnrecoverableError();
return;
}
@@ -392,7 +392,7 @@ void ProfileSyncService::StartProcessingChangesIfReady() {
UMA_HISTOGRAM_TIMES("Sync.BookmarkAssociationTime",
base::TimeTicks::Now() - start_time);
if (!merge_success) {
- LOG(ERROR) << "Model assocation failed.";
+ LOG(ERROR) << "Model association failed.";
OnUnrecoverableError();
return;
}
@@ -122,7 +122,7 @@ void ProfileSyncService::StartUp() {
registrar_.Add(this, NotificationType::BOOKMARK_MODEL_LOADED,
Source<Profile>(profile_));
- // Create new model assocation manager and change processor.
+ // Create new model association manager and change processor.
model_associator_ = new ModelAssociator(this);
change_processor_->set_model_associator(model_associator_);